@@ -1,6 +1,7 @@
 from __future__ import print_function
 import cmor
 import numpy
+import tempfile
 import sys
 import os
 from time import localtime, strftime
@@ -25,6 +26,11 @@ if len(sys.argv) > 2:
 else:
     shuffle = int(os.environ.get("SHUFFLE", 0))
 
+if len(sys.argv) > 3:
+    print_summary = int(sys.argv[3])
+else:
+    print_summary = 0
+
 if level == 0:
     deflate = 0
 else:
@@ -36,9 +42,10 @@ f.close()
 s = s.replace("${DEFLATE_LEVEL}", str(level))
 s = s.replace("${DEFLATE}", str(deflate))
 s = s.replace("${SHUFFLE}", str(shuffle))
-f = open("mytable", "w")
-f.write(s)
-f.close()
+file_handle, file_path = tempfile.mkstemp(prefix='cmor_speed_and_compression', suffix='.json', dir='.')
+with open(file_path,'w') as f:
+    f.write(s)
+mytable = os.path.basename(file_path)
 
 cmor.setup(
     inpath="Tables",
@@ -48,8 +55,9 @@ cmor.setup(
 cmor.dataset_json("Test/CMOR_input_example.json")
 
 tables = []
-tables.append(cmor.load_table("mytable"))
+tables.append(cmor.load_table(mytable))
 print('Tables ids:', tables)
+os.remove(file_path)
 
 
 # read in data, just one slice
@@ -159,6 +167,8 @@ for i in range(10):
     a = dic.get((i, 0), "N/A")
     b = dic.get((i, 1), "N/A")
     print('Level: ', i, "no suffle:", a, "shuffle", b)
-f = open("summary.txt", "w")
-f.write(repr(dic))
-f.close()
+
+if print_summary != 0:
+    f = open("summary.txt", "w")
+    f.write(repr(dic))
+    f.close()
