@@ -7,7 +7,7 @@ def main():
 
     cmor.setup(inpath='Tables',
                netcdf_file_action=cmor.CMOR_REPLACE_3)
-    cmor.dataset_json("Test/common_user_input.json")
+    cmor.dataset_json("Test/CMOR_input_example.json")
 
     table = 'CMIP6_Amon.json'
     cmor.load_table(table)
