@@ -40,7 +40,7 @@ class TestCase(base_CMIP6_CV.BaseCVsTest):
                 inpath='TestTables',
                 logfile=self.tmpfile,
                 netcdf_file_action=cmor.CMOR_REPLACE)
-            cmor.dataset_json("Test/CMOR_input_example.json")
+            cmor.dataset_json("Test/CMOR_input_TestTables.json")
 
             # ------------------------------------------
             # load Omon table and create masso variable
